@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 10850 2018-03-17 23:41:09Z David $
+# $Id: models.py 10870 2018-03-18 15:01:05Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-18 07:41:09 +0800 (Sun, 18 Mar 2018) $
-# $Revision: 10850 $
+# $Date: 2018-03-18 23:01:05 +0800 (Sun, 18 Mar 2018) $
+# $Revision: 10870 $
 
 from emencia.django.newsletter.models import Newsletter, Contact
 
@@ -30,7 +30,7 @@ class Header(models.Model):
         help_text=_('Custom your header content.'))
 
     def __unicode__(self):
-        return 'Header %s' % (str(self.id), ) 
+        return _('Header %s') % (str(self.id), ) 
 
     class Meta:
         verbose_name = _('Header')
@@ -46,7 +46,7 @@ class Footer(models.Model):
         help_text=_('Custom your footer content.'))
 
     def __unicode__(self):
-         return 'Footer %s' % (str(self.id), ) 
+         return _('Footer %s') % (str(self.id), ) 
 
     class Meta:
         verbose_name = _('Footer')
